@@ -11,6 +11,33 @@ import numpy as np
 
 REGISTRY = {}
 
+def totask(task):
+  if isinstance(task, RegisteredTask):
+    return task
+
+  if type(task) is bytes:
+    task = task.decode('utf8')
+
+  if isinstance(task, six.string_types):
+    task = json.loads(task)
+
+  ident = task.get('id', -1)
+
+  if 'payload' in task:
+    task = task['payload']
+
+  taskobj = deserialize(task)
+  taskobj._id = ident
+  return taskobj
+
+def totaskid(taskid):
+  if isinstance(taskid, RegisteredTask):
+    return taskid.id
+  elif 'id' in taskid:
+    return taskid['id']
+    
+  return taskid
+
 def deserialize(data):
   if type(data) is bytes:
     data = data.decode('utf8')
