@@ -302,8 +302,9 @@ class TaskQueue(object):
     stop_fn: A boolean returning function that accepts no parameters. When
       it returns True, the task execution loop will terminate. It is evaluated
       once after every task. If you provide the arguments `executed` (tasks completed) 
-      `tries` (current attempts at fetching a task), or `previous_execution_time` (time in
-      seconds to run the last task) they will be dependency injected.
+      `tries` (current attempts at fetching a task), `previous_execution_time` (time in
+      seconds to run the last task), or `elapsed_time` (time since polling started in 
+      seconds) they will be dependency injected.
     before_fn: Pass task pre-execution.
     after_fn: Pass task post-execution.
     verbose: print out the status of each step
@@ -342,6 +343,7 @@ class TaskQueue(object):
 
     tries = 0
     executed = 0
+    total_elapsed_sec = 0
 
     backoff = False
     backoff_exceptions = tuple(list(backoff_exceptions) + [ QueueEmptyError ])
@@ -349,7 +351,10 @@ class TaskQueue(object):
     before_fn = before_fn or (lambda x: x)
     after_fn = after_fn or (lambda x: x)
 
+    loop_init_time = time.time()
+
     while LOOP:
+      total_elapsed_sec = time.time() - loop_init_time
       task = 'unknown' # for error message prior to leasing
       try:
         task = self.lease(seconds=int(lease_seconds))
@@ -379,6 +384,8 @@ class TaskQueue(object):
         stop_fn_bound = partial(stop_fn_bound, tries=tries)
       if 'previous_execution_time' in varnames:
         stop_fn_bound = partial(stop_fn_bound, previous_execution_time=time_delta) 
+      if 'elapsed_time' in varnames:
+        stop_fn_bound = partial(stop_fn_bound, elapsed_time=total_elapsed_sec) 
 
       if stop_fn_bound():
         break
